@@ -41,11 +41,11 @@
 //--------------------------------------------
 - free
 {
-  free (inpLy);
-  free (Wgts1);
-  free (hidLy);
-  free (Wgts2);
-  free (opLy);
+  xfree (inpLy);
+  xfree (Wgts1);
+  xfree (hidLy);
+  xfree (Wgts2);
+  xfree (opLy);
   [self drop];
 
   return nil;
